ResponsiveBreakpoints class

Configuración de breakpoints personalizados para responsive design

Annotations

Constructors

ResponsiveBreakpoints({double mobile = 0, double tablet = 600, double desktop = 1200, Map<String, double>? custom})
const

Properties

custom Map<String, double>?
final
desktop double
final
hashCode int
The hash code for this object.
no setterinherited
mobile double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablet double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultBreakpoints → const ResponsiveBreakpoints
Breakpoints por defecto